@@ -343,7 +343,7 @@ class NovaAdminClient(object):
                                            {'Name': name},
                                            UserInfo)
         except boto.exception.BotoServerError, e:
-            if e.status == 400 and e.error_code == 'NotFound':
+            if e.status == 400 and e.error_code == 'UserNotFound':
                 return None
             raise
 
